![Unit test run](https://github.com/kt1720/Data-533-Group-16-project/actions/workflows/python-package.yml/badge.svg)

# Data-533-Group-16-project
## Description
Our plan is to create a household budgeting tool called `mybudgeter`. 
The program will allow individual users to set and check budgets for a number of spending categories they choose.
Users will also be able to add, modify, and delete individual transactions, categorize their spending and set a budget for each category. 
If a user's spending is over his/her set budget, the program will alarm the user.
The program will allow users to create a brand new SQLite database to store their spending and budget data if it's the first time using the program or import the data from a SQLite database if it's previously created.
Users will also have the option to perform basic budget calculations, read or visualize simple budget summary, and visualize spending vs. budget trends.
